@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001, 2002, 2003, 2004 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "/home/scons/scons/branch.0/branch.96/baseline/src/engine/SCons/Scanner/Prog.py 0.96.93.D001 2006/11/06 08:31:54 knight"
+__revision__ = "src/engine/SCons/Scanner/Prog.py 2949 2008/05/17 23:07:00 knight"
 
 import string
 
@@ -54,10 +54,8 @@ def scan(node, env, libpath = ()):
         return []
     if SCons.Util.is_String(libs):
         libs = string.split(libs)
-    elif SCons.Util.is_List(libs):
-        libs = SCons.Util.flatten(libs)
     else:
-        libs = [libs]
+        libs = SCons.Util.flatten(libs)
 
     try:
         prefix = env['LIBPREFIXES']
@@ -80,8 +78,9 @@ def scan(node, env, libpath = ()):
 
     result = []
 
-    if callable(libpath): libpath = libpath()
-    
+    if callable(libpath):
+        libpath = libpath()
+
     find_file = SCons.Node.FS.find_file
     adjustixes = SCons.Util.adjustixes
     for lib in libs:
