@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,14 +31,15 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "/home/scons/scons/branch.0/branch.96/baseline/src/engine/SCons/Tool/midl.py 0.96.93.D001 2006/11/06 08:31:54 knight"
+__revision__ = "src/engine/SCons/Tool/midl.py 2949 2008/05/17 23:07:00 knight"
+
+import string
 
 import SCons.Action
 import SCons.Builder
 import SCons.Defaults
 import SCons.Scanner.IDL
 import SCons.Util
-import SCons.Tool.msvs
 
 def midl_emitter(target, source, env):
     """Produces a list of outputs from the MIDL compiler"""
@@ -46,11 +47,17 @@ def midl_emitter(target, source, env):
     tlb = target[0]
     incl = base + '.h'
     interface = base + '_i.c'
-    proxy = base + '_p.c'
-    dlldata = base + '_data.c'
+    t = [tlb, incl, interface]
 
-    t = [tlb, incl, interface, proxy, dlldata]
+    midlcom = env['MIDLCOM']
 
+    if string.find(midlcom, '/proxy') != -1:
+        proxy = base + '_p.c'
+        t.append(proxy)
+    if string.find(midlcom, '/dlldata') != -1:
+        dlldata = base + '_data.c'
+        t.append(dlldata)
+    
     return (t,source)
 
 idl_scanner = SCons.Scanner.IDL.IDLScan()
@@ -72,6 +79,10 @@ def generate(env):
     env['BUILDERS']['TypeLibrary'] = midl_builder
 
 def exists(env):
+    if not env['PLATFORM'] in ('win32', 'cygwin'):
+        return 0
+
+    import SCons.Tool.msvs
     if SCons.Tool.msvs.is_msvs_installed():
         # there's at least one version of MSVS installed, which comes with midl:
         return 1
