@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,7 +31,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "/home/scons/scons/branch.0/branch.96/baseline/src/engine/SCons/Tool/msvc.py 0.96.93.D001 2006/11/06 08:31:54 knight"
+__revision__ = "src/engine/SCons/Tool/msvc.py 2949 2008/05/17 23:07:00 knight"
 
 import os.path
 import re
@@ -138,12 +138,13 @@ def _parse_msvc8_overrides(version,platform,suite):
     if not SCons.Util.can_read_reg:
         raise SCons.Errors.InternalError, "No Windows registry module was found"
 
-    s = ''
+    # XXX This code assumes anything that isn't EXPRESS uses the default
+    # registry key string.  Is this really true for all VS suites?
     if suite == 'EXPRESS':
         s = '\\VCExpress\\'
+    else:
+        s = '\\VisualStudio\\'
 
-    # ToDo: add registry key strings for the other versions of visual
-    # studio 2005.
     settings_path = ""
     try:
         (settings_path, t) = SCons.Util.RegGetValue(SCons.Util.HKEY_CURRENT_USER,
@@ -202,6 +203,11 @@ def _parse_msvc8_overrides(version,platform,suite):
         user_settings = doc.getElementsByTagName('UserSettings')[0]
         tool_options = user_settings.getElementsByTagName('ToolsOptions')[0]
         tool_options_categories = tool_options.getElementsByTagName('ToolsOptionsCategory')
+        environment_var_map = {
+            'IncludeDirectories' : 'INCLUDE',
+            'LibraryDirectories' : 'LIBRARY',
+            'ExecutableDirectories' : 'PATH',
+        }
         for category in tool_options_categories:
             category_name = category.attributes.get('name')
             if category_name is not None and category_name.value == 'Projects':
@@ -214,21 +220,21 @@ def _parse_msvc8_overrides(version,platform,suite):
                             property_name = property.attributes.get('name')
                             if property_name is None:
                                 continue
-                            elif property_name.value == 'IncludeDirectories':
-                                include_dirs = property.childNodes[0].data
-                                # ToDo: Support for other destinations than Win32
-                                include_dirs = include_dirs.replace('Win32|', '')
-                                dirs['INCLUDE'] = include_dirs
-                            elif property_name.value == 'LibraryDirectories':
-                                lib_dirs = property.childNodes[0].data.replace('Win32|', '')
-                                # ToDo: Support for other destinations than Win32
-                                lib_dirs = lib_dirs.replace('Win32|', '')
-                                dirs['LIBRARY'] = lib_dirs
-                            elif property_name.value == 'ExecutableDirectories':
-                                path_dirs = property.childNodes[0].data.replace('Win32|', '')
-                                # ToDo: Support for other destinations than Win32
-                                path_dirs = path_dirs.replace('Win32|', '')
-                                dirs['PATH'] = path_dirs
+                            var_name = environment_var_map.get(property_name)
+                            if var_name:
+                                data = property.childNodes[0].data
+                                value_list = string.split(data, '|')
+                                if len(value_list) == 1:
+                                    dirs[var_name] = value_list[0]
+                                else:
+                                    while value_list:
+                                        dest, value = value_list[:2]
+                                        del value_list[:2]
+                                        # ToDo: Support for destinations
+                                        # other than Win32
+                                        if dest == 'Win32':
+                                            dirs[var_name] = value
+                                            break
     else:
         # There are no default directories in the registry for VS8 Express :(
         raise SCons.Errors.InternalError, "Unable to find MSVC paths in the registry."
@@ -512,10 +518,6 @@ def _get_msvc8_default_paths(env, version, suite, use_mfc_dirs):
                 include_paths.append( os.path.join( atlmfc_path, 'include' ) )
                 lib_paths.append( os.path.join( atlmfc_path, 'lib' ) )
 
-        env_include_path = SCons.Util.get_environment_var('INCLUDE')
-        if env_include_path:
-            include_paths.append( env_include_path )
-
         if SCons.Util.can_read_reg and paths.has_key('FRAMEWORKSDKDIR'):
             fwdir = paths['FRAMEWORKSDKDIR']
             include_paths.append( os.path.join( fwdir, 'include' ) )
@@ -599,7 +601,7 @@ def get_msvc_default_paths(env, version=None, use_mfc_dirs=0):
     version_num, suite = SCons.Tool.msvs.msvs_parse_version(version)
     if version_num >= 8.0:
         suite = SCons.Tool.msvs.get_default_visualstudio8_suite(env)
-        defpaths = _get_msvc8_default_paths(env, version, suite, use_mfc_dirs)
+        return _get_msvc8_default_paths(env, version, suite, use_mfc_dirs)
     elif version_num >= 7.0:
         return _get_msvc7_default_paths(env, version, use_mfc_dirs)
     else:
@@ -687,10 +689,12 @@ def generate(env):
     env['CCCOMFLAGS'] = '$CPPFLAGS $_CPPDEFFLAGS $_CPPINCFLAGS /c $SOURCES /Fo$TARGET $CCPCHFLAGS $CCPDBFLAGS'
     env['CC']         = 'cl'
     env['CCFLAGS']    = SCons.Util.CLVar('/nologo')
-    env['CCCOM']      = '$CC $CCFLAGS $CCCOMFLAGS'
+    env['CFLAGS']     = SCons.Util.CLVar('')
+    env['CCCOM']      = '$CC $CFLAGS $CCFLAGS $CCCOMFLAGS'
     env['SHCC']       = '$CC'
     env['SHCCFLAGS']  = SCons.Util.CLVar('$CCFLAGS')
-    env['SHCCCOM']    = '$SHCC $SHCCFLAGS $CCCOMFLAGS'
+    env['SHCFLAGS']   = SCons.Util.CLVar('$CFLAGS')
+    env['SHCCCOM']    = '$SHCC $SHCFLAGS $SHCCFLAGS $CCCOMFLAGS'
     env['CXX']        = '$CC'
     env['CXXFLAGS']   = SCons.Util.CLVar('$CCFLAGS $( /TP $)')
     env['CXXCOM']     = '$CXX $CXXFLAGS $CCCOMFLAGS'
