@@ -10,7 +10,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -32,7 +32,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "/home/scons/scons/branch.0/branch.96/baseline/src/engine/SCons/Tool/qt.py 0.96.93.D001 2006/11/06 08:31:54 knight"
+__revision__ = "src/engine/SCons/Tool/qt.py 2949 2008/05/17 23:07:00 knight"
 
 import os.path
 import re
@@ -66,7 +66,7 @@ def checkMocIncluded(target, source, env):
     cpp = source[0]
     # looks like cpp.includes is cleared before the build stage :-(
     # not really sure about the path transformations (moc.cwd? cpp.cwd?) :-/
-    path = SCons.Defaults.CScan.path_function(env, moc.cwd)
+    path = SCons.Defaults.CScan.path(env, moc.cwd)
     includes = SCons.Defaults.CScan(cpp, env, path)
     if not moc in includes:
         SCons.Warnings.warn(
@@ -75,7 +75,6 @@ def checkMocIncluded(target, source, env):
             (str(moc), str(cpp)))
 
 def find_file(filename, paths, node_factory):
-    retval = None
     for dir in paths:
         node = node_factory(filename, dir)
         if node.rexists():
@@ -219,7 +218,6 @@ def uicEmitter(target, source, env):
     return target, source
 
 def uicScannerFunc(node, env, path):
-    dir = node.dir
     lookout = []
     lookout.extend(env['CPPPATH'])
     lookout.append(str(node.rfile().dir))
@@ -231,18 +229,17 @@ def uicScannerFunc(node, env, path):
             result.append(dep)
     return result
 
-uicScanner = SCons.Scanner.Scanner(uicScannerFunc,
-                                   name = "UicScanner", 
-                                   node_class = SCons.Node.FS.File,
-                                   node_factory = SCons.Node.FS.File,
-                                   recursive = 0)
+uicScanner = SCons.Scanner.Base(uicScannerFunc,
+                                name = "UicScanner", 
+                                node_class = SCons.Node.FS.File,
+                                node_factory = SCons.Node.FS.File,
+                                recursive = 0)
 
 def generate(env):
     """Add Builders and construction variables for qt to an Environment."""
     CLVar = SCons.Util.CLVar
     Action = SCons.Action.Action
     Builder = SCons.Builder.Builder
-    splitext = SCons.Util.splitext
 
     env.SetDefault(QTDIR  = _detect(env),
                    QT_BINPATH = os.path.join('$QTDIR', 'bin'),
@@ -313,8 +310,8 @@ def generate(env):
     env['BUILDERS']['Uic'] = uicBld
     env['BUILDERS']['Moc'] = mocBld
     static_obj, shared_obj = SCons.Tool.createObjBuilders(env)
-    static_obj.src_builder.append('Uic')
-    shared_obj.src_builder.append('Uic')
+    static_obj.add_src_builder('Uic')
+    shared_obj.add_src_builder('Uic')
 
     # We use the emitters of Program / StaticLibrary / SharedLibrary
     # to scan for moc'able files
